Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Eastern ¶
Eastern returns a *time.Location for the US Eastern region. RTP requires all timestamps are in this location.
func MessageID ¶ added in v0.2.0
MessageID formats a FedNow Message Identification which is a reference assigned by the sender of the message. A MessageID is composed of
- the Calendar Date (8 numeric characters, CCYYMMDD),
- sender's FedNow Connection Party Identification (9 alphanumeric characters)
- a reference assigned by the sender (up to 18 alphanumeric characters)
Types ¶
type ErrorCode ¶
type ErrorCode struct {
Code string
Description string
Level ErrorLevel
}
type ErrorLevel ¶
type ErrorLevel string
const ( // ErrAccountFatal indicates a problem with the (Creditor) account. // It likely should be reverified. ErrAccountFatal ErrorLevel = "Fatal error for the Account" // ErrFatal indicates a problem that likely requires a human be notified. ErrFatal ErrorLevel = "Fatal error" // ErrTemporary indicates a problem which should go away with time. ErrTemporary ErrorLevel = "Temporary" // ErrNetwork indicates a problem with the network / connection. ErrNetwork ErrorLevel = "Network issue" // ErrLogic indicates a bug to fix or work around. ErrLogic ErrorLevel = "Logic Bug" )
func (ErrorLevel) Error ¶
func (e ErrorLevel) Error() string
type ISODate ¶
ISODate is a custom type wrapping time.Time
func (ISODate) MarshalText ¶
func (ISODate) MarshalXML ¶ added in v0.2.0
func (*ISODate) UnmarshalXML ¶ added in v0.2.0
type ISODateTime ¶
func (ISODateTime) MarshalText ¶
func (i ISODateTime) MarshalText() (string, error)
func (ISODateTime) MarshalXML ¶ added in v0.2.0
func (i ISODateTime) MarshalXML(e *xml.Encoder, start xml.StartElement) error
func (*ISODateTime) UnmarshalXML ¶ added in v0.2.0
func (i *ISODateTime) UnmarshalXML(d *xml.Decoder, start xml.StartElement) error
Click to show internal directories.
Click to hide internal directories.